Package: OneTwoSamples
Type: Package
Title: Deal with One and Two (Normal) Samples
Version: 1.3-0
Date: 2026-06-06
Authors@R: c(
	person(given = "Frederic", family= "Bertrand", role = c("cre"), email = "frederic.bertrand@lecnam.net", comment = c(ORCID = "0000-0002-0837-8281")),
	person(given = "Ying-Ying", family= "Zhang (Robert)", role = c("aut")))
Author: Frederic Bertrand [cre] (ORCID:
    <https://orcid.org/0000-0002-0837-8281>),
  Ying-Ying Zhang (Robert) [aut]
Maintainer: Frederic Bertrand <frederic.bertrand@lecnam.net>
Depends: R (>= 3.3), methods
Suggests: testthat (>= 3.0.0), roxygen2
Description: We introduce an R function
        one_two_sample() which can deal with one and two (normal)
        samples, Ying-Ying Zhang, Yi Wei (2012) <doi:10.2991/asshm-13.2013.29>. 
        For one normal sample x, the function reports
        descriptive statistics, plot, interval estimation and test of
        hypothesis of x. For two normal samples x and y, the function
        reports descriptive statistics, plot, interval estimation and
        test of hypothesis of x and y, respectively. It also reports
        interval estimation and test of hypothesis of mu1-mu2 (the
        difference of the means of x and y) and sigma1^2 / sigma2^2
        (the ratio of the variances of x and y), tests whether x and y
        are from the same population, finds the correlation coefficient
        of x and y if x and y have the same length.
License: GPL (>= 2)
LazyLoad: yes
Encoding: UTF-8
Config/testthat/edition: 3
RoxygenNote: 7.3.3
URL: https://github.com/fbertran/OneTwoSamples,
        https://fbertran.github.io/OneTwoSamples/
BugReports: https://github.com/fbertran/OneTwoSamples/issues
NeedsCompilation: no
Packaged: 2026-06-06 14:55:18 UTC; bertran7
Repository: CRAN
Date/Publication: 2026-06-06 16:40:02 UTC
Built: R 4.5.2; ; 2026-06-06 20:35:11 UTC; unix
