# Generated by roxygen2: do not edit by hand

export(data_outline)
export(detail)
export(interval_estimate1)
export(interval_estimate2)
export(interval_estimate3)
export(interval_estimate4)
export(interval_estimate5)
export(interval_var1)
export(interval_var2)
export(interval_var3)
export(interval_var4)
export(mean_test1)
export(mean_test2)
export(one_sample)
export(one_two_sample)
export(p_value)
export(var_test1)
export(var_test2)
importFrom(grDevices,dev.new)
importFrom(grDevices,graphics.off)
importFrom(graphics,hist)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(methods,show)
importFrom(stats,binom.test)
importFrom(stats,cor.test)
importFrom(stats,density)
importFrom(stats,dnorm)
importFrom(stats,ecdf)
importFrom(stats,ks.test)
importFrom(stats,median)
importFrom(stats,pchisq)
importFrom(stats,pf)
importFrom(stats,pnorm)
importFrom(stats,pt)
importFrom(stats,qchisq)
importFrom(stats,qf)
importFrom(stats,qnorm)
importFrom(stats,qqline)
importFrom(stats,qqnorm)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,shapiro.test)
importFrom(stats,t.test)
importFrom(stats,var)
importFrom(stats,var.test)
importFrom(stats,wilcox.test)
